@@ -18,6 +18,7 @@
 
 from collections import defaultdict
 from collections import deque
+from collections import namedtuple
 import difflib
 import functools
 import importlib.resources
@@ -28,11 +29,6 @@ import textwrap
 
 from turberfield.catchphrase.parser import CommandParser
 
-# From Addison Arches
-from collections import namedtuple
-
-Action = namedtuple(
-    "Action", ["name", "rel", "typ", "ref", "method", "parameters", "prompt"])
 
 
 class Drama:
@@ -55,7 +51,6 @@ class Drama:
     * interpret
 
     """
-    Parameter = namedtuple("Parameter", ["name", "required", "regex", "values", "tip"])
     Record = namedtuple("Record", ["fn", "args", "kwargs", "lines"])
 
     @classmethod
@@ -69,13 +64,6 @@ class Drama:
             return method
         return decorator
 
-    @staticmethod
-    def build():
-        """
-        FIXME: Docs
-        """
-        return []
-
     @staticmethod
     @functools.cache
     def load_dialogue(pkg, resource):
@@ -142,8 +130,8 @@ class Drama:
     def turns(self):
         return len(self.history)
 
-    def build(self):
-        yield from []
+    def build(self, ensemble=None):
+        yield from ensemble or []
 
     def add(self, *args):
         for item in args:
@@ -175,6 +163,7 @@ class Drama:
         except (IndexError, KeyError):
             yield (None, [text], {})
 
+    # TODO: Move to a mixin
     def do_help(self, key, text):
         """
         help | ?
