@@ -13,9 +13,12 @@
 # You should have received a copy of the GNU General Public License
 # along with turberfield.  If not, see <http://www.gnu.org/licenses/>.
 
+from collections import namedtuple
 import functools
+import html
 import re
 import textwrap
+import urllib.parse
 
 from turberfield.catchphrase.drama import Drama
 from turberfield.catchphrase.presenter import Presenter
@@ -32,6 +35,10 @@ catchphrase-colour-shadows
 
 """
 
+Action = namedtuple("Action", ["name", "rel", "typ", "ref", "method", "parameters", "prompt"])
+Parameter = namedtuple("Parameter", ["name", "required", "regex", "values", "tip"])
+
+
 class Settings(DataObject):
     pass
 
@@ -88,86 +95,70 @@ preload="auto" {'loop="loop"' if anim.element.loop and int(anim.element.loop) >
 </div>"""
 
     @staticmethod
-    def render_action_form(parameters=[], validator=re.compile("[\\w ]+")):
-        if parameters:
-            yield '<form role="form" action="/drama/action/" method="POST" name="action">'
+    def render_action_form(action: Action, autofocus=False):
+        url = urllib.parse.quote(action.typ.format(*action.ref))
+        if action.parameters:
+            yield f'<form role="form" action="{url}" method="{action.method}" name="{action.name}">'
             yield "<fieldset>"
 
-        for p in parameters:
+        for p in action.parameters:
+            typ = "hidden" if p.required == "hidden" else "text"
             if not p.tip.endswith("."):
-                yield f"<label>{p.tip}</label>"
+                yield f'<label for="input-{p.name}-{typ}" id="input-{p.name}-{typ}-tip">{html.escape(p.tip)}</label>'
             if not p.values:
                 yield textwrap.dedent(f"""
                     <input
                     name="{p.name}"
                     pattern="{p.regex.pattern if p.regex else ''}"
                     {'required="required"' if p.required else ''}
+                    {'autofocus="autofocus"' if autofocus else ''}
                     type="{'hidden' if p.required == 'hidden' else 'text'}"
-                    title="{p.tip}"
+                    title="{html.escape(p.tip)}"
                     />""")
             elif len(p.values) == 1:
                 yield textwrap.dedent(f"""
                     <input
                     name="{p.name}"
-                    value="{p.values[0]}"
                     placeholder="{p.values[0]}"
                     pattern="{p.regex.pattern if p.regex else ''}"
                     {'required="required"' if p.required else ''}
+                    {'autofocus="autofocus"' if autofocus else ''}
                     type="{'hidden' if p.required == 'hidden' else 'text'}"
-                    title="{p.tip}"
+                    title="{html.escape(p.tip)}"
                     />""")
             else:
                 yield f'<select name="{p.name}">'
                 for v in p.values:
                     yield f'<option value="{v}">{v}</option>'
                 yield "</select>"
-        if parameters:
+
+        yield f'<button type="submit">{action.prompt}</button>'
+
+        if action.parameters:
             yield "</fieldset>"
             yield "</form>"
 
     @staticmethod
-    def render_command_form(placeholder="?", validator=re.compile("[\\w ]+")):
-        return f"""
-<form role="form" action="/drama/cmd/" method="POST" name="cmd">
-<fieldset>
-<label for="input-cmd-text" id="input-cmd-text-tip">&gt;</label>
-<input
-name="cmd"
-type="text"
-id="input-cmd-text"
-required="required"
-autofocus="autofocus"
-aria-describedby="input-cmd-text"
-placeholder="{placeholder}"
-pattern="{validator.pattern}"
->
-<button type="submit">Enter</button>
-</fieldset>
-</form>"""
+    def render_frame_to_terminal(frame, ensemble=[], title="", backnav=""):
+        for i in frame[Model.Line]:
+            if i.element.text:
+                yield (Renderer.animated_line_to_terminal(i), i.duration)
 
     @staticmethod
-    def render_frame_to_html(
-        frame,
-        ensemble=[], options=[],
-        prompt="?", title="", backnav="", actions=False, commands=True
-    ):
-        heading = " ".join("<span>{0}</span>".format(i.capitalize()) for i in title.split(" "))
+    def render_dict_to_css(mapping=None, tag=":root"):
+        mapping = mapping or {}
+        entries = "\n".join("--{0}: {1};".format(k, v) for k, v in mapping.items())
+        return "{tag} {{\n{entries}\n}}".format(tag=tag, entries=entries)
+
+    @staticmethod
+    def render_animated_frame_to_html(frame, controls=[]):
         dialogue = "\n".join(Renderer.animated_line_to_html(i) for i in frame[Model.Line])
         stills = "\n".join(Renderer.animated_still_to_html(i) for i in frame[Model.Still])
         audio = "\n".join(Renderer.animated_audio_to_html(i) for i in frame[Model.Audio])
         last = frame[Model.Line][-1] if frame[Model.Line] else Presenter.Animation(0, 0, None)
-        controls = [Renderer.render_command_form(placeholder=prompt)] if commands else []
-        if actions:
-            controls.extend(
-                Renderer.render_action_form(list(reversed(op.parameters)))
-                for op in actions if hasattr(op, "parameters")
-            )
         controls = "\n".join(Renderer.animate_controls(*controls, delay=last.delay + last.duration, dwell=0.3))
         return f"""
 {audio}
-<section class="catchphrase-banner">
-<h1>{heading}</h1>
-</section>
 <aside class="catchphrase-reveal">
 {stills}
 </aside>
@@ -182,22 +173,11 @@ pattern="{validator.pattern}"
 </ul>
 </nav>"""
 
-    @staticmethod
-    def render_frame_to_terminal(frame, ensemble=[], title="", backnav=""):
-        for i in frame[Model.Line]:
-            if i.element.text:
-                yield (Renderer.animated_line_to_terminal(i), i.duration)
-
-    @staticmethod
-    def render_dict_to_css(mapping=None, tag=":root"):
-        mapping = mapping or {}
-        entries = "\n".join("--{0}: {1};".format(k, v) for k, v in mapping.items())
-        return "{tag} {{\n{entries}\n}}".format(tag=tag, entries=entries)
-
     @staticmethod
     @functools.lru_cache()
     def render_body_html(title="", refresh=None, next_="", base_style="/css/base/catchphrase.css"):
         base_link = '<link rel="stylesheet" href="{0}" />'.format(base_style) if base_style else ""
+        heading = " ".join("<span>{0}</span>".format(i.capitalize()) for i in title.split(" "))
         return f"""<!DOCTYPE html>
 <html lang="en">
 <head>
@@ -213,6 +193,9 @@ pattern="{validator.pattern}"
 <style type="text/css">
 {{1}}
 </style>
+<section class="catchphrase-banner">
+<h1>{heading}</h1>
+</section>
 {{2}}
 </body>
 </html>"""
